#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: menumaker
# PROJECT HOMEPAGE 	: http://menumaker.sourceforge.net/
# SOURCES          	: http://downloads.sourceforge.net/menumaker/menumaker-0.99.7.tar.gz?modtime=1134484860&big_mirror=0
#
# AUTHOR         	: skywatcher (skywatcher|AT|netsons|DOT|org, simone antoniucci)
# LATEST REVISION	: 2008-04-20

### Setting main variables
NAME="menumaker"
VERSION="0.99.7"
ARCH="i486"
CPU="i686"
BUILD=52.1

HOMEPAGE="http://menumaker.sourceforge.net"
DESCRIPTION="Menu creation utility"
SRCLNK="http://downloads.sourceforge.net/menumaker/$NAME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=$NAME-$VERSION.tar.gz
SRCDIR=$CWD/$NAME-$VERSION
#ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		
#ICONDIR=$PKGDIR/usr/share/icons/hicolor/scalable/apps/	

BASE=http://users.zenwalk.org/user-accounts/skywatcher/$NAME

DOCS="AUTHORS ChangeLog COPYING INSTALL NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
#mkdir -p $PKGDIR/usr/share/applications
#mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Configure, make, install
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/info -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: MenuMaker is a menu generation utility. It is capable of finding 
$NAME: lots of installed programs and generating a root menu consistent 
$NAME: across all supported X window managers, so one will get (almost) 
$NAME: the same menu no matter what window manager is selected. It is 
$NAME: pure Python application hence it runs on every relevant system.
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5sum and dep
cd $CWD
md5sum $PKG.tgz > $PKG.md5
requiredbuilder -z $PKG.tgz > $PKG.dep

### Requirements for src management
cp -a $PKGDIR/install/slack-desc $PKG.txt
SFILE=$NAME-$VERSION-noarch-$BUILD
rm -fr $SFILE.src
for link in $SRCLNK
	do echo $link >> $SFILE.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Ending it all
echo "To install type: installpkg $PKG.tgz"
echo "To upgrade type: upgradepkg $PKG.tgz"

### Done. Ciao!
